@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -54,8 +54,7 @@ bool
 Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
 {
     rcsc::dlog.addText( rcsc::Logger::TEAM,
-                        "%s:%d: Bhv_BasicOffensiveKick"
-                        ,__FILE__, __LINE__ );
+                        __FILE__": Bhv_BasicOffensiveKick" );
 
     const rcsc::WorldModel & wm = agent->world();
 
@@ -91,8 +90,7 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
             if ( safety )
             {
                 rcsc::dlog.addText( rcsc::Logger::TEAM,
-                                    "%s:%d: do best pass"
-                                    ,__FILE__, __LINE__ );
+                                    __FILE__": (execute) do best pass" );
                 agent->debugClient().addMessage( "OffKickPass(1)" );
                 rcsc::Body_Pass().execute( agent );
                 agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
@@ -106,8 +104,7 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
         if ( rcsc::Body_Pass().execute( agent ) )
         {
             rcsc::dlog.addText( rcsc::Logger::TEAM,
-                                "%s:%d: do best pass"
-                                ,__FILE__, __LINE__ );
+                                __FILE__": (execute) do best pass" );
             agent->debugClient().addMessage( "OffKickPass(2)" );
             agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
             return true;
@@ -142,14 +139,13 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
             if ( ! wm.existOpponentIn( sector, 10, true ) )
             {
                 rcsc::dlog.addText( rcsc::Logger::TEAM,
-                                    "%s:%d: dribble to my body dir"
-                                    ,__FILE__, __LINE__ );
+                                    __FILE__": (execute) dribble to my body dir" );
                 agent->debugClient().addMessage( "OffKickDrib(1)" );
-                rcsc::Body_Dribble2008( body_dir_drib_target,
-                                        1.0,
-                                        rcsc::ServerParam::i().maxDashPower(),
-                                        2
-                                        ).execute( agent );
+                rcsc::Body_Dribble( body_dir_drib_target,
+                                    1.0,
+                                    rcsc::ServerParam::i().maxDashPower(),
+                                    2
+                                    ).execute( agent );
                 agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
                 return true;
             }
@@ -183,29 +179,27 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
             }
 
             rcsc::dlog.addText( rcsc::Logger::TEAM,
-                                "%s:%d: fast dribble to (%.1f, %.1f) max_step=%d"
-                                ,__FILE__, __LINE__,
+                                __FILE__": (execute) fast dribble to (%.1f, %.1f) max_step=%d",
                                 drib_target.x, drib_target.y,
                                 max_dash_step );
             agent->debugClient().addMessage( "OffKickDrib(2)" );
-            rcsc::Body_Dribble2008( drib_target,
-                                    1.0,
-                                    rcsc::ServerParam::i().maxDashPower(),
-                                    std::min( 5, max_dash_step )
-                                    ).execute( agent );
+            rcsc::Body_Dribble( drib_target,
+                                1.0,
+                                rcsc::ServerParam::i().maxDashPower(),
+                                std::min( 5, max_dash_step )
+                                ).execute( agent );
         }
         else
         {
             rcsc::dlog.addText( rcsc::Logger::TEAM,
-                                "%s:%d: slow dribble to (%f, %f)"
-                                ,__FILE__, __LINE__,
+                                __FILE__": (execute) slow dribble to (%.1f, %.1f)",
                                 drib_target.x, drib_target.y );
             agent->debugClient().addMessage( "OffKickDrib(3)" );
-            rcsc::Body_Dribble2008( drib_target,
-                                    1.0,
-                                    rcsc::ServerParam::i().maxDashPower(),
-                                    2
-                                    ).execute( agent );
+            rcsc::Body_Dribble( drib_target,
+                                1.0,
+                                rcsc::ServerParam::i().maxDashPower(),
+                                2
+                                ).execute( agent );
 
         }
         agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
@@ -216,15 +210,14 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
     if ( nearest_opp_dist > 5.0 )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
-                            "%s:%d: opp far. dribble(%f, %f)"
-                            ,__FILE__, __LINE__,
+                            __FILE__": opp far. dribble(%.1f, %.1f)",
                             drib_target.x, drib_target.y );
         agent->debugClient().addMessage( "OffKickDrib(4)" );
-        rcsc::Body_Dribble2008( drib_target,
-                                1.0,
-                                rcsc::ServerParam::i().maxDashPower() * 0.4,
-                                1
-                                ).execute( agent );
+        rcsc::Body_Dribble( drib_target,
+                            1.0,
+                            rcsc::ServerParam::i().maxDashPower() * 0.4,
+                            1
+                            ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
         return true;
     }
@@ -235,8 +228,8 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
     if ( rcsc::Body_Pass().execute( agent ) )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
-                            "%s:%d: pass"
-                            ,__FILE__, __LINE__ );
+                            __FILE__": (execute) pass",
+                            __LINE__ );
         agent->debugClient().addMessage( "OffKickPass(3)" );
         agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
         return true;
@@ -246,15 +239,14 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
     if ( nearest_opp_dist > 3.0 )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
-                            "%s:%d: opp far. dribble(%f, %f)"
-                            ,__FILE__, __LINE__,
+                            __FILE__": (execute) opp far. dribble(%f, %f)",
                             drib_target.x, drib_target.y );
         agent->debugClient().addMessage( "OffKickDrib(5)" );
-        rcsc::Body_Dribble2008( drib_target,
-                                1.0,
-                                rcsc::ServerParam::i().maxDashPower() * 0.2,
-                                1
-                                ).execute( agent );
+        rcsc::Body_Dribble( drib_target,
+                            1.0,
+                            rcsc::ServerParam::i().maxDashPower() * 0.2,
+                            1
+                            ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
         return true;
     }
@@ -262,8 +254,7 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
     if ( nearest_opp_dist > 2.5 )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
-                            "%s:%d: hold"
-                            ,__FILE__, __LINE__ );
+                            __FILE__": hold" );
         agent->debugClient().addMessage( "OffKickHold" );
         rcsc::Body_HoldBall().execute( agent );
         agent->setNeckAction( new rcsc::Neck_TurnToLowConfTeammate() );
@@ -273,8 +264,7 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
     if ( wm.self().pos().x > wm.offsideLineX() - 10.0 )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
-                            "%s:%d: kick near side"
-                            ,__FILE__, __LINE__ );
+                            __FILE__": kick near side" );
         agent->debugClient().addMessage( "OffKickToCorner" );
         Body_KickToCorner( (wm.self().pos().y < 0.0) ).execute( agent );
         agent->setNeckAction( new rcsc::Neck_ScanField() );
@@ -282,8 +272,7 @@ Bhv_BasicOffensiveKick::execute( rcsc::PlayerAgent * agent )
     else
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
-                            "%s:%d: advance"
-                            ,__FILE__, __LINE__ );
+                            __FILE__": clear" );
         agent->debugClient().addMessage( "OffKickAdvance" );
         rcsc::Body_AdvanceBall().execute( agent );
         agent->setNeckAction( new rcsc::Neck_ScanField() );
