@@ -30,16 +30,10 @@
 #include <rcsc/geom/vector_2d.h>
 #include <rcsc/player/soccer_action.h>
 
-class Strategy;
-
 class Bhv_PreProcess
     : public rcsc::SoccerBehavior {
-private:
-    const Strategy & M_strategy;
 public:
-    explicit
-    Bhv_PreProcess( const Strategy & strat )
-        : M_strategy( strat )
+    Bhv_PreProcess()
       { }
 
     bool execute( rcsc::PlayerAgent * agent );
