@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -36,7 +36,6 @@
 #include <rcsc/action/body_go_to_point.h>
 #include <rcsc/action/body_intercept.h>
 #include <rcsc/action/body_kick_one_step.h>
-#include <rcsc/action/body_kick_two_step.h>
 #include <rcsc/action/neck_scan_field.h>
 #include <rcsc/action/neck_turn_to_ball_or_scan.h>
 
@@ -57,10 +56,10 @@ bool
 Bhv_TheirGoalKickMove::execute( rcsc::PlayerAgent * agent )
 {
     static const rcsc::Rect2D
-        expand_their_penalty( rcsc::ServerParam::i().theirPenaltyAreaLineX() - 0.75,
-                              -rcsc::ServerParam::i().penaltyAreaHalfWidth() - 0.75,
-                              rcsc::ServerParam::i().penaltyAreaLength() + 0.75,
-                              rcsc::ServerParam::i().penaltyAreaWidth() + 1.5 );
+        expand_their_penalty( rcsc::Vector2D( rcsc::ServerParam::i().theirPenaltyAreaLineX() - 0.75,
+                                              -rcsc::ServerParam::i().penaltyAreaHalfWidth() - 0.75 ),
+                              rcsc::Size2D( rcsc::ServerParam::i().penaltyAreaLength() + 0.75,
+                                            rcsc::ServerParam::i().penaltyAreaWidth() + 1.5 ) );
 
     const rcsc::WorldModel & wm = agent->world();
 
@@ -112,7 +111,7 @@ Bhv_TheirGoalKickMove::execute( rcsc::PlayerAgent * agent )
     }
 
     double dash_power
-        = wm.self().getSafetyDashPower( rcsc::ServerParam::i().maxPower() * 0.8 );
+        = wm.self().getSafetyDashPower( rcsc::ServerParam::i().maxDashPower() * 0.8 );
 
     if ( intersection.x < rcsc::ServerParam::i().theirPenaltyAreaLineX()
          && wm.self().pos().x > rcsc::ServerParam::i().theirPenaltyAreaLineX() - 0.5 )
@@ -216,10 +215,9 @@ Bhv_TheirGoalKickMove::doChaseBall( rcsc::PlayerAgent * agent )
 
     const double pen_x = rcsc::ServerParam::i().theirPenaltyAreaLineX() - 1.0;
     const double pen_y = rcsc::ServerParam::i().penaltyAreaHalfWidth() + 1.0;
-    const rcsc::Rect2D their_penalty( pen_x,
-                                      -pen_y,
-                                      rcsc::ServerParam::i().penaltyAreaLength() + 1.0,
-                                      rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 );
+    const rcsc::Rect2D their_penalty( rcsc::Vector2D( pen_x, -pen_y ),
+                                      rcsc::Size2D( rcsc::ServerParam::i().penaltyAreaLength() + 1.0,
+                                                    rcsc::ServerParam::i().penaltyAreaWidth() - 2.0 ) );
     if ( their_penalty.contains( get_pos ) )
     {
         return false;
