@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -81,6 +81,28 @@ main( int argc, char ** argv )
         return EXIT_FAILURE;
     }
 
+    /*
+      You should add your copyright message here.
+     */
+    // std::cout << "*****************************************************************\n"
+    //           << " This program is modified by <Team Name>\n"
+    //           << " Copyright 20xx. <Your name>.\n"
+    //           << " <Affiliation>\n"
+    //           << " All rights reserved.\n"
+    //           << "*****************************************************************\n"
+    //           << std::flush;
+
+    /*
+      Do NOT remove the following copyright notice!
+     */
+    std::cout << "*****************************************************************\n"
+              << " This program is based on agent2d created by Hidehisa Akiyama.\n"
+              << " Copyright 2006 - 2009. Hidehisa Akiyama.\n"
+              << " National Institute of Advanced Industrial Science and Technology\n"
+              << " All rights reserved.\n"
+              << "*****************************************************************\n"
+              << std::flush;
+
     client.run( &agent );
 
     return EXIT_SUCCESS;
