@@ -34,9 +34,10 @@ class RoleCenterBack
 private:
 
 public:
-    explicit
-    RoleCenterBack( boost::shared_ptr< const rcsc::Formation > f )
-        : SoccerRole( f )
+
+    static const std::string NAME;
+
+    RoleCenterBack()
       { }
 
     ~RoleCenterBack()
@@ -45,21 +46,24 @@ public:
     virtual
     void execute( rcsc::PlayerAgent * agent );
 
+
     static
-    std::string name()
+    const
+    std::string & name()
       {
-          return std::string( "CenterBack" );
+          return NAME;
       }
 
     static
-    SoccerRole * create( boost::shared_ptr< const rcsc::Formation > f )
+    SoccerRole::Ptr create()
       {
-          return ( new RoleCenterBack( f ) );
+          SoccerRole::Ptr ptr( new RoleCenterBack() );
+          return ptr;
       }
+
 private:
 
     void doKick( rcsc::PlayerAgent * agent );
-
     void doMove( rcsc::PlayerAgent * agent );
 };
 
