@@ -34,9 +34,10 @@ class RoleCenterForward
 private:
 
 public:
-    explicit
-    RoleCenterForward( boost::shared_ptr< const Formation > f )
-        : SoccerRole( f )
+
+    static const std::string NAME;
+
+    RoleCenterForward()
       { }
 
     ~RoleCenterForward()
@@ -45,21 +46,23 @@ public:
     virtual
     void execute( rcsc::PlayerAgent * agent );
 
+
     static
-    std::string name()
+    const
+    std::string & name()
       {
-          return std::string( "CenterForward" );
-      }
-    static
-    SoccerRole * create( boost::shared_ptr< const Formation > f )
-      {
-          return ( new RoleCenterForward( f ) );
+          return NAME;
       }
 
+    static
+    SoccerRole::Ptr create()
+      {
+          SoccerRole::Ptr ptr( new RoleCenterForward() );
+          return ptr;
+      }
 private:
 
     void doKick( rcsc::PlayerAgent * agent );
-
     void doMove( rcsc::PlayerAgent * agent );
 };
 
