@@ -35,9 +35,9 @@ private:
 
 public:
 
-    explicit
-    RoleDefensiveHalf( boost::shared_ptr< const rcsc::Formation > f )
-        : SoccerRole( f )
+    static const std::string NAME;
+
+    RoleDefensiveHalf()
       { }
 
     ~RoleDefensiveHalf()
@@ -48,20 +48,22 @@ public:
 
 
     static
-    std::string name()
+    const
+    std::string & name()
       {
-          return std::string( "DefensiveHalf" );
+          return NAME;
       }
+
     static
-    SoccerRole * create( boost::shared_ptr< const rcsc::Formation > f )
+    SoccerRole::Ptr create()
       {
-          return ( new RoleDefensiveHalf( f ) );
+          SoccerRole::Ptr ptr( new RoleDefensiveHalf() );
+          return ptr;
       }
 
 private:
 
     void doKick( rcsc::PlayerAgent * agent );
-
     void doMove( rcsc::PlayerAgent * agent );
 };
 
