@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -46,6 +46,18 @@
 #include <rcsc/common/server_param.h>
 #include <rcsc/geom/rect_2d.h>
 
+
+const std::string RoleGoalie::NAME( "Goalie" );
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+namespace {
+rcss::RegHolder role = SoccerRole::creators().autoReg( &RoleGoalie::create,
+                                                       RoleGoalie::name() );
+}
+
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -63,7 +75,8 @@ RoleGoalie::execute( rcsc::PlayerAgent* agent )
     // play_on play
 
     // catchable
-    if ( agent->world().time().cycle() > M_last_goalie_kick_time.cycle() + 5
+    if ( agent->world().time().cycle()
+         > agent->world().self().catchTime().cycle() + rcsc::ServerParam::i().catchBanCycle()
          && agent->world().ball().distFromSelf() < agent->world().self().catchableArea() - 0.05
          && our_penalty.contains( agent->world().ball().pos() ) )
     {
