@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -44,6 +44,18 @@
 #include <rcsc/common/logger.h>
 #include <rcsc/common/server_param.h>
 
+
+const std::string RoleOffensiveHalf::NAME( "OffensiveHalf" );
+
+/*-------------------------------------------------------------------*/
+/*!
+
+ */
+namespace {
+rcss::RegHolder role = SoccerRole::creators().autoReg( &RoleOffensiveHalf::create,
+                                                       RoleOffensiveHalf::NAME );
+}
+
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -100,34 +112,10 @@ RoleOffensiveHalf::doKick( rcsc::PlayerAgent * agent )
 void
 RoleOffensiveHalf::doMove( rcsc::PlayerAgent * agent )
 {
-    const rcsc::WorldModel & wm = agent->world();
+    rcsc::Vector2D home_pos = Strategy::i().getPosition( agent->world().self().unum() );
+    if ( ! home_pos.valid() ) home_pos.assign( 0.0, 0.0 );
 
-    int ball_reach_step = 0;
-    if ( ! wm.existKickableTeammate()
-         && ! wm.existKickableOpponent() )
-    {
-        ball_reach_step
-            = std::min( wm.interceptTable()->teammateReachCycle(),
-                        wm.interceptTable()->opponentReachCycle() );
-    }
-    const rcsc::Vector2D base_pos
-        = wm.ball().inertiaPoint( ball_reach_step );
-
-    rcsc::Vector2D home_pos
-        = formation().getPosition( agent->config().playerNumber(),
-                                   base_pos );
-    if ( rcsc::ServerParam::i().useOffside() )
-    {
-        home_pos.x = std::min( home_pos.x, wm.offsideLineX() - 1.0 );
-    }
-
-    rcsc::dlog.addText( rcsc::Logger::ROLE,
-                        "%s: HOME POSITION=(%.2f, %.2f) base_point(%.1f %.1f)"
-                        ,__FILE__,
-                        home_pos.x, home_pos.y,
-                        base_pos.x, base_pos.y );
-
-    switch ( Strategy::get_ball_area( base_pos ) ) {
+    switch ( Strategy::get_ball_area( agent->world() ) ) {
     case Strategy::BA_CrossBlock:
     case Strategy::BA_Stopper:
     case Strategy::BA_Danger:
