@@ -35,9 +35,9 @@ private:
 
 public:
 
-    explicit
-    RoleSideBack( boost::shared_ptr< const Formation > f )
-        : SoccerRole( f )
+    static const std::string NAME;
+
+    RoleSideBack()
       { }
 
     ~RoleSideBack()
@@ -46,20 +46,23 @@ public:
     virtual
     void execute( rcsc::PlayerAgent * agent );
 
+
     static
-    std::string name()
+    const
+    std::string & name()
       {
-          return std::string( "SideBack" );
+          return NAME;
       }
+
     static
-    SoccerRole * create( boost::shared_ptr< const Formation > f )
+    SoccerRole::Ptr create()
       {
-          return ( new RoleSideBack( f ) );
+          SoccerRole::Ptr ptr( new RoleSideBack() );
+          return ptr;
       }
 private:
 
     void doKick( rcsc::PlayerAgent * agent );
-
     void doMove( rcsc::PlayerAgent * agent );
 };
 
