@@ -7,7 +7,7 @@
 
  This code is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2, or (at your option)
+ the Free Software Foundation; either version 3, or (at your option)
  any later version.
 
  This code is distributed in the hope that it will be useful,
@@ -30,6 +30,7 @@
 
 #include "sample_player.h"
 
+#include "strategy.h"
 #include "soccer_role.h"
 
 #include "bhv_goalie_free_kick.h"
@@ -37,8 +38,10 @@
 #include "bhv_pre_process.h"
 #include "bhv_set_play.h"
 #include "bhv_set_play_kick_in.h"
+#include "bhv_set_play_indirect_free_kick.h"
 
 #include <rcsc/formation/formation.h>
+#include <rcsc/action/kick_table.h>
 #include <rcsc/player/intercept_table.h>
 #include <rcsc/player/say_message_builder.h>
 #include <rcsc/player/audio_sensor.h>
@@ -116,6 +119,11 @@ SamplePlayer::~SamplePlayer()
 bool
 SamplePlayer::initImpl( rcsc::CmdLineParser & cmd_parser )
 {
+    bool result = rcsc::PlayerAgent::initImpl( cmd_parser );
+
+    // read additional options
+    result &= Strategy::instance().init( cmd_parser );
+
     rcsc::ParamMap my_params;
 #if 0
     std::string formation_conf;
@@ -123,27 +131,30 @@ SamplePlayer::initImpl( rcsc::CmdLineParser & cmd_parser )
         ( &formation_conf, "fconf" )
         ;
 
-    cmd_parser.parse( my_params );
+    result &= cmd_parser.parse( my_params );
 #endif
 
-    if ( ! rcsc::PlayerAgent::initImpl( cmd_parser ) )
+    if ( cmd_parser.count( "help" ) > 0 )
     {
         my_params.printHelp( std::cout );
-        M_client->setServerAlive( false );
+        return false;
+    }
+
+    if ( ! result )
+    {
         return false;
     }
 
     if ( cmd_parser.failed() )
     {
-        std::cerr << "player: ***WARNING*** detected invalid options: ";
+        std::cerr << "player: ***WARNING*** detected unsupported options: ";
         cmd_parser.print( std::cerr );
         std::cerr << std::endl;
     }
 
-    if ( ! M_strategy.read( config().configDir() ) )
+    if ( ! Strategy::instance().read( config().configDir() ) )
     {
         std::cerr << "***ERROR*** Failed to read team strategy." << std::endl;
-        M_client->setServerAlive( false );
         return false;
     }
 
@@ -185,13 +196,19 @@ SamplePlayer::actionImpl()
                   << std::endl;
     }
 
+    //
+    // update strategy (formation, ...)
+    //
+
+    Strategy::instance().update( world() );
+
     //////////////////////////////////////////////////////////////
     // check tackle expires
     // check self position accuracy
     // ball search
     // check queued intention
     // check simultaneous kick
-    if ( Bhv_PreProcess( M_strategy ).execute( this ) )
+    if ( Bhv_PreProcess().execute( this ) )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
                             "%s:%d: preprocess done"
@@ -201,9 +218,7 @@ SamplePlayer::actionImpl()
 
     //////////////////////////////////////////////////////////////
     // create current role
-    boost::shared_ptr< SoccerRole >
-        role_ptr = M_strategy.createRole( config().playerNumber(),
-                                          world() );
+    SoccerRole::Ptr role_ptr = Strategy::i().createRole( world().self().unum(), world() );
 
     if ( ! role_ptr )
     {
@@ -214,15 +229,6 @@ SamplePlayer::actionImpl()
         M_client->setServerAlive( false );
         return;
     }
-    if  ( ! role_ptr->hasFormation() )
-    {
-        std::cerr << config().teamName() << ": "
-                  << world().self().unum()
-                  << " Error. does not have formation.\nExit ..."
-                  << std::endl;
-        M_client->setServerAlive( false );
-        return;
-    }
 
     //////////////////////////////////////////////////////////////
     // play_on mode
@@ -232,6 +238,22 @@ SamplePlayer::actionImpl()
         return;
     }
 
+    rcsc::Vector2D home_pos = Strategy::i().getPosition( world().self().unum() );
+    if ( ! home_pos.valid() )
+    {
+        std::cerr << config().teamName() << ": "
+                  << world().self().unum()
+                  << " ***ERROR*** illegal home position."
+                  << std::endl;
+        home_pos.assign( 0.0, 0.0 );
+    }
+
+    debugClient().addLine( rcsc::Vector2D( home_pos.x, home_pos.y - 0.25 ),
+                           rcsc::Vector2D( home_pos.x, home_pos.y + 0.25 ) );
+    debugClient().addLine( rcsc::Vector2D( home_pos.x - 0.25, home_pos.y ),
+                           rcsc::Vector2D( home_pos.x + 0.25, home_pos.y ) );
+    debugClient().addCircle( home_pos, 0.5 );
+
     //////////////////////////////////////////////////////////////
     // kick_in or corner_kick
     if ( ( world().gameMode().type() == rcsc::GameMode::KickIn_
@@ -244,23 +266,25 @@ SamplePlayer::actionImpl()
         }
         else
         {
-            const rcsc::Vector2D base_pos = world().ball().pos();
-            rcsc::Vector2D home_pos
-                = role_ptr->formation().getPosition( config().playerNumber(),
-                                                     base_pos );
             Bhv_SetPlayKickIn( home_pos ).execute( this );
         }
         return;
     }
 
+    //////////////////////////////////////////////////////////////
+    if ( world().gameMode().type() == rcsc::GameMode::BackPass_
+         || world().gameMode().type() == rcsc::GameMode::IndFreeKick_ )
+    {
+        Bhv_SetPlayIndirectFreeKick( home_pos ).execute( this );
+        return;
+    }
 
     //////////////////////////////////////////////////////////////
     // penalty kick mode
     if ( world().gameMode().isPenaltyKickMode() )
     {
         rcsc::dlog.addText( rcsc::Logger::TEAM,
-                            "%s:%d: penalty kick"
-                            ,__FILE__, __LINE__ );
+                            __FILE__": penalty kick" );
         Bhv_PenaltyKick().execute( this );
         return;
     }
@@ -276,14 +300,51 @@ SamplePlayer::actionImpl()
     //////////////////////////////////////////////////////////////
     // other set play mode
 
-    rcsc::Vector2D move_pos
-        = M_strategy.getSetPlayPosition( config().playerNumber(),
-                                         role_ptr->formation(),
-                                         world() );
+    Bhv_SetPlay( home_pos ).execute( this );
+}
 
-    //////////////////////////////////////////////////////////////
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+SamplePlayer::handleServerParam()
+{
+    if ( rcsc::KickTable::instance().createTables() )
+    {
+        std::cerr << world().teamName() << ' '
+                  << world().self().unum() << ": "
+                  << " KickTable created."
+                  << std::endl;
+    }
+    else
+    {
+        std::cerr << world().teamName() << ' '
+                  << world().self().unum() << ": "
+                  << " KickTable failed..."
+                  << std::endl;
+        M_client->setServerAlive( false );
+    }
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+SamplePlayer::handlePlayerParam()
+{
+
+}
+
+/*-------------------------------------------------------------------*/
+/*!
+
+*/
+void
+SamplePlayer::handlePlayerType()
+{
 
-    Bhv_SetPlay( move_pos ).execute( this );
 }
 
 /*-------------------------------------------------------------------*/
@@ -522,52 +583,7 @@ SamplePlayer::sayIntercept()
         debugClient().addMessage( "Sayi_self" );
         return true;
     }
-#if 0
-    else
-    {
-        {
-            const rcsc::PlayerObject * mate = world().interceptTable()->fastestTeammate();
 
-            if ( mate
-                 && mate->unum() != rcsc::Unum_Unknown
-                 && mate->posCount() <= 0
-                 && mate->distFromSelf() <= 15.0
-                 && mate_min <= 10
-                 && mate_min <= self_min + 1
-                 && mate_min <= opp_min + 1 )
-            {
-                addSayMessage( new rcsc::InterceptMessage( true,
-                                                           mate->unum(),
-                                                           mate_min ) );
-                rcsc::dlog.addText( rcsc::Logger::TEAM,
-                                    __FILE__": say teammate intercept info %d",
-                                    mate_min );
-                debugClient().addMessage( "Sayi_our" );
-                return true;
-            }
-        }
-        {
-            const rcsc::PlayerObject * opp = world().interceptTable()->fastestOpponent();
-            if ( opp
-                 && opp->unum() != rcsc::Unum_Unknown
-                 && opp->posCount() <= 0
-                 && opp->distFromSelf() <= 15.0
-                 && opp_min <= 10
-                 && opp_min <= self_min + 1
-                 && opp_min <= mate_min + 1 )
-            {
-                addSayMessage( new rcsc::InterceptMessage( false,
-                                                           opp->unum(),
-                                                           opp_min ) );
-                rcsc::dlog.addText( rcsc::Logger::TEAM,
-                                    __FILE__": say opponent intercept info %d",
-                                    opp_min );
-                debugClient().addMessage( "Sayi_opp" );
-                return true;
-            }
-        }
-    }
-#endif
     return false;
 }
 
@@ -604,7 +620,6 @@ SamplePlayer::sayOffsideLine()
     return false;
 }
 
-
 /*-------------------------------------------------------------------*/
 /*!
 
@@ -700,8 +715,7 @@ SamplePlayer::saySelf()
     if ( send_self )
     {
         addSayMessage( new rcsc::OnePlayerMessage( world().self().unum(),
-                                                   effector().queuedNextMyPos(),
-                                                   effector().queuedNextMyBody() ) );
+                                                   effector().queuedNextMyPos() ) );
         rcsc::dlog.addText( rcsc::Logger::TEAM,
                             __FILE__": say self status" );
         debugClient().addMessage( "Say1_self" );
